@@ -1,7 +1,7 @@
 from deskbar.core.Utils import get_xdg_data_dirs
 from gettext import gettext as _
 from os.path import join, exists
-import deskbar.core.gnomedesktop
+import gnomedesktop
 import deskbar.interfaces.Action
 import logging
 
@@ -15,7 +15,7 @@ class OpenDesktopFileAction(deskbar.interfaces.Action):
     
     def __init__(self, name, desktop, desktop_file, executable):
         """
-        @type desktop: L{deskbar.core.gnomedesktop.GnomeDesktopItem}
+        @type desktop: L{gnomedesktop.DesktopItem}
         @type desktop_file: path pointing to .desktop file
         @param executeable: Name of the executeable for display 
         """
@@ -74,17 +74,17 @@ def parse_desktop_filename(desktop, only_if_visible=True):
 
 def parse_desktop_file(desktop, only_if_visible=True):
     try:
-        desktop = deskbar.core.gnomedesktop.item_new_from_file(desktop, deskbar.core.gnomedesktop.LOAD_ONLY_IF_EXISTS)
+        desktop = gnomedesktop.item_new_from_file(desktop, gnomedesktop.LOAD_ONLY_IF_EXISTS)
     except Exception, e:
         LOGGER.warning('Couldn\'t read desktop file %s:', desktop)
         LOGGER.exception(e)
         return None
     
-    if desktop == None or desktop.get_entry_type() != deskbar.core.gnomedesktop.TYPE_APPLICATION:
+    if desktop == None or desktop.get_entry_type() != gnomedesktop.TYPE_APPLICATION:
         return None
-    if desktop.get_boolean(deskbar.core.gnomedesktop.KEY_TERMINAL):
+    if desktop.get_boolean(gnomedesktop.KEY_TERMINAL):
         return None
-    if only_if_visible and desktop.get_boolean(deskbar.core.gnomedesktop.KEY_NO_DISPLAY):
+    if only_if_visible and desktop.get_boolean(gnomedesktop.KEY_NO_DISPLAY):
         return None
         
     return desktop
\ No newline at end of file
